import { Component, Input, OnChanges, SimpleChanges, ViewChild, ElementRef } from '@angular/core';
import { highlightText } from './core';

@Component({
  selector: 'universal-text-highlight',
  template: `
    <div #container>
      <span [innerHTML]="highlightedText"></span>
      <div *ngIf="enableNavigation && matches.length > 0">
        <button (click)="prevHighlight()">Previous</button>
        <button (click)="nextHighlight()">Next</button>
      </div>
    </div>
  `
})
export class UniversalTextHighlightComponent implements OnChanges {
  @Input() text: string;
  @Input() highlight: string | string[];
  @Input() caseSensitive: boolean = false;
  @Input() enableNavigation: boolean = false;

  @ViewChild('container') containerRef: ElementRef;

  highlightedText: string;
  matches: any[] = [];
  currentHighlightIndex: number = -1;

  ngOnChanges(changes: SimpleChanges) {
    this.updateHighlight();
  }

  updateHighlight() {
    const { html, matches } = highlightText(this.text, this.highlight, this.caseSensitive, this.enableNavigation);
    this.highlightedText = html;
    this.matches = matches;
    this.currentHighlightIndex = -1;
  }

  nextHighlight() {
    if (this.currentHighlightIndex < this.matches.length - 1) {
      this.currentHighlightIndex++;
      this.scrollToHighlight();
    }
  }

  prevHighlight() {
    if (this.currentHighlightIndex > 0) {
      this.currentHighlightIndex--;
      this.scrollToHighlight();
    }
  }

  scrollToHighlight() {
    if (this.enableNavigation && this.containerRef) {
      const highlight = this.containerRef.nativeElement.querySelector(`[data-index="${this.currentHighlightIndex}"]`);
      if (highlight) {
        highlight.scrollIntoView({ behavior: 'smooth', block: 'center' });
      }
    }
  }
}