export function highlightText(text, highlight, caseSensitive = false, enableNavigation = false) {
  if (!highlight) {
    return { html: text, matches: [] };
  }

  const highlights = Array.isArray(highlight) ? highlight : [highlight];
  let result = text;
  const matches = [];

  highlights.forEach(keyword => {
    if (keyword) {
      const regex = new RegExp(escapeRegExp(keyword), caseSensitive ? 'g' : 'gi');
      let match;
      let lastIndex = 0;
      while ((match = regex.exec(text)) !== null) {
        const start = match.index;
        const end = start + match[0].length;
        matches.push({ start, end });

        const before = result.slice(0, start + lastIndex);
        const highlighted = result.slice(start + lastIndex, end + lastIndex);
        const after = result.slice(end + lastIndex);

        result = before + `<mark class="universal-highlight" ${enableNavigation ? `data-index="${matches.length - 1}"` : ''}>${highlighted}</mark>` + after;

        lastIndex += `<mark class="universal-highlight" ${enableNavigation ? `data-index="${matches.length - 1}"` : ''}>`.length;
      }
    }
  });

  return { html: result, matches };
}

function escapeRegExp(string) {
  return string.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
}