import React, { useState, useEffect, useRef } from 'react';
import { highlightText } from './core';

export default function UniversalTextHighlight({ text, highlight, caseSensitive = false, enableNavigation = false }) {
  const [currentHighlightIndex, setCurrentHighlightIndex] = useState(-1);
  const [matches, setMatches] = useState([]);
  const containerRef = useRef(null);

  const { html, matches: newMatches } = highlightText(text, highlight, caseSensitive, enableNavigation);

  useEffect(() => {
    setMatches(newMatches);
    setCurrentHighlightIndex(-1);
  }, [text, highlight, caseSensitive]);

  const nextHighlight = () => {
    if (currentHighlightIndex < matches.length - 1) {
      setCurrentHighlightIndex(currentHighlightIndex + 1);
    }
  };

  const prevHighlight = () => {
    if (currentHighlightIndex > 0) {
      setCurrentHighlightIndex(currentHighlightIndex - 1);
    }
  };

  useEffect(() => {
    if (enableNavigation && containerRef.current) {
      const highlight = containerRef.current.querySelector(`[data-index="${currentHighlightIndex}"]`);
      if (highlight) {
        highlight.scrollIntoView({ behavior: 'smooth', block: 'center' });
      }
    }
  }, [currentHighlightIndex, enableNavigation]);

  return (
    <div ref={containerRef}>
    <span dangerouslySetInnerHTML={{ __html: html }} />
  {enableNavigation && matches.length > 0 && (
  <div>
  <button onClick={prevHighlight}>Previous</button>
    <button onClick={nextHighlight}>Next</button>
    </div>
  )}
</div>
);
}