import { highlightText } from './core';

export default {
  name: 'UniversalTextHighlight',
  props: {
    text: {
      type: String,
      required: true
    },
    highlight: {
      type: [String, Array],
      default: ''
    },
    caseSensitive: {
      type: Boolean,
      default: false
    },
    enableNavigation: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      currentHighlightIndex: -1,
      matches: []
    };
  },
  computed: {
    highlightedText() {
      const { html, matches } = highlightText(this.text, this.highlight, this.caseSensitive, this.enableNavigation);
      this.matches = matches;
      return html;
    }
  },
  methods: {
    nextHighlight() {
      if (this.currentHighlightIndex < this.matches.length - 1) {
        this.currentHighlightIndex++;
        this.scrollToHighlight();
      }
    },
    prevHighlight() {
      if (this.currentHighlightIndex > 0) {
        this.currentHighlightIndex--;
        this.scrollToHighlight();
      }
    },
    scrollToHighlight() {
      const highlight = this.$el.querySelector(`[data-index="${this.currentHighlightIndex}"]`);
      if (highlight) {
        highlight.scrollIntoView({ behavior: 'smooth', block: 'center' });
      }
    }
  },
  render(h) {
    return h('div', [
      h('span', {
        domProps: {
          innerHTML: this.highlightedText
        }
      }),
      this.enableNavigation && this.matches.length > 0 ? h('div', [
        h('button', { on: { click: this.prevHighlight } }, 'Previous'),
        h('button', { on: { click: this.nextHighlight } }, 'Next')
      ]) : null
    ]);
  }
}